package jp.co.intra_mart.cookbook.im_cookbook_119455_validate_fileupload;

import java.io.InputStream;
import java.util.List;
import java.util.Map;

import jp.co.intra_mart.foundation.forma.exception.FormaUserProcessException;
import jp.co.intra_mart.foundation.forma.fileupload.FormaFileUploadItemManager;
import jp.co.intra_mart.foundation.forma.fileupload.model.FileUploadFileInfoModel;
import jp.co.intra_mart.foundation.forma.userprogram.PostProcessExecutor;
import jp.co.intra_mart.foundation.forma.userprogram.PostProcessParameter;

public class PostProcess extends PostProcessExecutor {

    /*
     * 登録処理を行った場合に実行されます。
     * 
     * @param formaParam フォルマパラメータ
     * @param sendParam 送信パラメータ
     * @throws Exception 例外が発生
     */
    @Override
    public void regist(final PostProcessParameter formaParam, final Map<String, Object> sendParam) throws Exception {
        final String applicationId = formaParam.getApplicationId();
        final String insertId = formaParam.getInsertId();
        final String processKey = formaParam.getProcessKey();

        // 案件に紐付くファイル情報を取得
        final FormaFileUploadItemManager manager = new FormaFileUploadItemManager(applicationId);
        final Map<String, List<FileUploadFileInfoModel>> filesInfo = manager.getFilesInfo(insertId, processKey);

        // バリデーション対象のアイテムID
        final String itemId = "attach_fileupload_item1";
        // 添付ファイルが無い場合は処理なし
        if (!filesInfo.containsKey(itemId)) {
            return;
        }

        // 添付ファイルごとに判定を行う
        for (final FileUploadFileInfoModel fileInfo : filesInfo.get(itemId)) {
            // ファイル名のバリデーション
            final String fileName = fileInfo.getFileName();
            if (fileName.indexOf("_") != -1) {
                // ファイル名にアンダーバーが含まれる場合はエラー
                final FormaUserProcessException error = new FormaUserProcessException(new Exception("Files with an incorrect file name was attached.")); // ログに出力するエラーメッセージ
                error.setUserMessage("Files containing underscores in file names can not be attached. File name:" + fileName); // 画面に表示するエラーメッセージ
                error.setOutputLog(true);
                throw error;
            }

            InputStream stream = null;
            try {
	            // ファイルサイズのバリデーション
	            final FileUploadFileInfoModel file = manager.getFile(insertId, fileInfo.getFileId(), processKey); // ファイルの実体を取得
	            stream = file.getFile();
	            final int fileSize = stream.available();
	            if (fileSize >= 1048576) {
	                // ファイルサイズが1MB以上の場合はエラー
	                final FormaUserProcessException error = new FormaUserProcessException(new Exception("Files with an incorrect file size was attached.")); // ログに出力するエラーメッセージ
	                error.setUserMessage("Files of 1 MB or larger can not be attached. File name:" + fileName); // 画面に表示するエラーメッセージ
	                error.setOutputLog(true);
	                throw error;
	            }
            } finally {
            	if (stream != null) {
            		stream.close();
            	}
            }
        }
    }
}
